=====================
Installing on Windows
=====================

Windows is a difficult environment for Python-based projects like ours. We do
not provide our own packages for Windows. Instead, we partner with Bitnami_,
who provides builds containing Review Board with `Power Pack`_. These are
available as standalone installers and virtual machines.

See the `Review Board + Power Pack`_ Bitnami page to get started.

For production servers, we recommend using Linux (which you can run in a VM on
Windows).

Alternatively, we can host your Review Board server at RBCommons_.

.. _Bitnami: https://bitnami.com/
.. _Power Pack: https://www.reviewboard.org/powerpack/
.. _Review Board + Power Pack:
   https://bitnami.com/stack/reviewboard-plus-powerpack
.. _RBCommons: https://www.rbcommons.com/
